@@ -1,7 +1,7 @@
-from kucoin_futures.base_request.base_request import KumexBaseRestApi
+from kucoin_futures.base_request.base_request import KucoinFuturesBaseRestApi
 
 
-class GetToken(KumexBaseRestApi):
+class GetToken(KucoinFuturesBaseRestApi):
 
     def get_ws_token(self, is_private=False):
         """
@@ -16,3 +16,4 @@ class GetToken(KumexBaseRestApi):
         return self._request('POST', uri, auth=is_private)
 
 
+
